/**
 * Author: Andrei Heidelbacher
 * Time complexity: O(N)
 * Memory complexity: O(N)
 */

#include <fstream>
#include <vector>
#include <algorithm>

using namespace std;

const char IN_FILE[] = "transform.in";
const char OUT_FILE[] = "transform.out";

class Point {
 public:
  int x, y;

  Point(const int _x, const int _y):
   x(_x),
   y(_y) {}
};

class Move {
 public:
  bool type;
  int v0, v1;

  Move(const bool _type, const int _v0, const int _v1):
   type(_type),
   v0(_v0),
   v1(_v1) {}
};

class Matrix {
 public:
  Matrix(const int _n, const vector<Point> &ones):
   n(_n),
   points(ones),
   rows(vector<vector<int>>(n)),
   columns(vector<vector<int>>(n)) {
    for (int i = 0; i < 2 * n; ++i) {
      rows[points[i].x].push_back(i);
      columns[points[i].y].push_back(i);
    }
  }

  int size() const {
    return n;
  }

  int pairH(const int index) const {
    if (rows[points[index].x][0] == index)
      return rows[points[index].x][1];
    else
      return rows[points[index].x][0];
  }

  int pairV(const int index) const {
    if (columns[points[index].y][0] == index)
      return columns[points[index].y][1];
    else
      return columns[points[index].y][0];
  }

  vector<Move> getMoves() const {
    return moves;
  }

  void normalize() {
    vector<int> chosen = normalizedOrder();
    for (int i = 0, offset = 0; i < int(chosen.size()); ++i) {
      int begin = chosen[i], end = pairV(chosen[i]);
      swapRows(points[begin].x, offset);
      swapColumns(points[begin].y, offset);
      int now = begin, next = pairH(begin);
      while (next != end) {
        swapColumns(points[now].y + 1, points[next].y);
        now = next;
        next = pairV(now);
        swapRows(points[now].x + 1, points[next].x);
        now = next;
        next = pairH(now);
        ++offset;
      }
      ++offset;
    }
  }
 private:
  int n;
  vector<Point> points;
  vector<vector<int>> rows, columns;
  vector<Move> moves;

  void swapRows(const int r0, const int r1) {
    for (int i = 0; i < 2; ++i) {
      points[rows[r0][i]].x = r1;
      points[rows[r1][i]].x = r0;
    }
    swap(rows[r0], rows[r1]);
    moves.push_back(Move(false, r0, r1));
  }

  void swapColumns(const int c0, const int c1) {
    for (int i = 0; i < 2; ++i) {
      points[columns[c0][i]].y = c1;
      points[columns[c1][i]].y = c0;
    }
    swap(columns[c0], columns[c1]);
    moves.push_back(Move(true, c0, c1));
  }

  vector<int> normalizedOrder() {
    vector<pair<int, int>> cycles;
    vector<bool> visited = vector<bool>(2 * n, false);
    for (int i = 0; i < 2 * n; ++i) {
      if (!visited[i]) {
        int length = 0;
        int j = i;
        do {
          visited[j] = true;
          j = pairH(j);
          visited[j] = true;
          j = pairV(j);
          length += 2;
        } while (j != i);
        cycles.push_back(make_pair(length, i));
      }
    }
    vector<vector<int>> buckets = vector<vector<int>>(2 * n + 1, vector<int>());
    for (int i = 0; i < int(cycles.size()); ++i)
      buckets[cycles[i].first].push_back(i);
    vector<int> chosen;
    for (int length = 1; length <= 2 * n; ++length)
      for (int i = 0; i < int(buckets[length].size()); ++i)
        chosen.push_back(cycles[buckets[length][i]].second);
    return chosen;
  }
};

vector<Move> getMoves(Matrix from, Matrix to) {
  from.normalize();
  vector<Move> moves = from.getMoves();
  to.normalize();
  vector<Move> second = to.getMoves();
  reverse(second.begin(), second.end());
  moves.insert(moves.end(), second.begin(), second.end());
  return moves;
}

vector<Move> solvePermutation(const vector<int> &permutation, const bool type) {
  const int n = int(permutation.size());
  vector<int> values = vector<int>(n), position = vector<int>(n);
  for (int i = 0; i < n; ++i)
    values[i] = position[i] = i;
  vector<Move> moves;
  for (int i = 0; i < n; ++i) {
    const int x = values[i];
    const int y = permutation[i];
    moves.push_back(Move(type, position[x], position[y]));
    swap(values[position[x]], values[position[y]]);
    swap(position[x], position[y]);
  }
  return moves;
}

vector<Move> reduceMoves(const int n, const vector<Move> &moves) {
  vector<int> rows = vector<int>(n), columns = vector<int>(n);
  for (int i = 0; i < n; ++i)
    rows[i] = columns[i] = i;
  for (int i = 0; i < int(moves.size()); ++i) {
    if (moves[i].type)
      swap(columns[moves[i].v0], columns[moves[i].v1]);
    else
      swap(rows[moves[i].v0], rows[moves[i].v1]);
  }
  vector<Move> reduced = solvePermutation(rows, false);
  vector<Move> columnMoves = solvePermutation(columns, true);
  reduced.insert(reduced.end(), columnMoves.begin(), columnMoves.end());
  return reduced;
}

vector<Move> solve(const Matrix &from, const Matrix &to) {
  const int n = int(from.size());
  return reduceMoves(n, getMoves(from, to));
}

pair<Matrix, Matrix> read() {
  ifstream in(IN_FILE);
  int n;
  in >> n;
  vector<Matrix> matrices;
  for (int i = 0; i < 2; ++i) {
    vector<Point> points;
    for (int i = 0; i < 2 * n; ++i) {
      int x, y;
      in >> x >> y;
      points.push_back(Point(x - 1, y - 1));
    }
    matrices.push_back(Matrix(n, points));
  }
  in.close();
  return make_pair(matrices[1], matrices[0]);
}

void write(const vector<Move> &moves) {
  ofstream out(OUT_FILE);
  for (int i = 0; i < int(moves.size()); ++i)
    out << (moves[i].type ? 'C' : 'L') << " " <<
        moves[i].v0 + 1 << " " <<
        moves[i].v1 + 1 << "\n";
  out << "0 0 0\n";
  out.close();
}

int main() {
  pair<Matrix, Matrix> input = read();
  vector<Move> moves = solve(input.first, input.second);
  write(moves);
  return 0;
}
